.gsdFastEdit .fast-edit-dropdown{display:inline-block;position:relative}.gsdFastEdit table{max-width:600px;margin-bottom:0}.gsdFastEdit table:hover tr,.gsdFastEdit table:hover td{background:transparent}.gsdFastEdit .items{margin-top:20px}.gsdFastEdit.working{pointer-events:none}.gsdFastEdit table td{vertical-align:middle}.gsdFastEdit .text-right{text-align:right}.gsdFastEdit .gsd-btn-toolbar [class^="icon-"]{margin:0}.gsdFastEdit .modal-body{overflow:hidden !important}.gsdFastEdit .icon-new{margin-right:5px}.gsdFastEdit .gsdID{opacity:.5}.gsdFastEdit .nowrap{white-space:nowrap}.gsdFastEdit .dropdown-menu{width:100%;padding:0;border-radius:5px}.gsdFastEdit .dropdown-menu li:first-child a{border-radius:5px 5px 0 0}.gsdFastEdit .dropdown-menu li:last-child a{border-radius:0 0 5px 5px}.gsdFastEdit .dropdown-menu a{display:block;padding:8px 10px;color:inherit !important;line-height:1;text-decoration:none;border-bottom:solid 1px #efefef}.gsdFastEdit .dropdown-menu a:hover{background-color:#efefef}fieldset#fieldset-gsd{border:none;padding:0;margin:0}fieldset#fieldset-gsd legend{display:none}


