.gsd-oh-container{margin-top:15px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.gsd-oh-container .clockpicker{margin-left:-5px;display:inline-block}.gsd-oh-container .clockpicker input{width:35px;padding:4px 8px}.gsd-oh-container>:not(:last-child){margin-bottom:12px}.gsd-oh-container .gsd-oh-row{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;min-height:28px}.gsd-oh-container .gsd-oh-row input[type="checkbox"]{margin:0 8px 0 0}.gsd-oh-container .gsd-oh-row label{margin:0 10px 0 0;width:90px}.gsd-oh-container .gsd-oh-row .oh-picker.first{display:none}.gsd-oh-container .gsd-oh-row .oh-picker.is-visible{display:block}.gsd-oh-container .gsd-oh-row a{display:inline-block;margin-left:10px;text-decoration:none;color:#3071a9}.gsd-oh-container .gsd-oh-row a.is-hidden{display:none}.gsd-oh-container .gsd-oh-row a:before{color:#3071a9}.gsd-oh-container .gsd-oh-row a.gsd-oh-more-btn,.gsd-oh-container .gsd-oh-row a.gsd-oh-add-btn{float:left;width:auto}.gsd-oh-container .gsd-oh-row a.gsd-oh-add-btn{margin-left:0}.gsd-oh-container .gsd-oh-row a.gsd-oh-add-btn span{display:inline-block;margin-left:5px;font-family:var(--body-font-family, Arial)}.gsd-oh-container .gsd-oh-row a.gsd-oh-add-btn span.is-hidden{display:none}.gsd-oh-container .gsd-oh-row .oh-more{margin-left:20px;display:none}.gsd-oh-container .gsd-oh-row .oh-more.is-visible{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.nr-app.j4 .gsd-oh-container .clockpicker input{width:60px}


