.subform{margin-left:-180px}.subform .subform-child{display:-webkit-box;display:-ms-flexbox;display:flex}.subform .subform-child .controls{margin:0}.subform .subform-child .controls>*{width:100% !important;-webkit-box-sizing:border-box;box-sizing:border-box}.subform .subform-child .controls>input{height:28px}.nr-main-container{background-color:#f0f0f0}.nr-main-container .tf-notices:not(:empty){padding:20px}.nr-main-container .tf-notices:not(:empty) .tf-notice:last-of-type{margin-bottom:0}.subhead-collapse{-webkit-box-shadow:0 2px 2px 2px rgba(0,0,0,0.06);box-shadow:0 2px 2px 2px rgba(0,0,0,0.06);position:relative;z-index:1}.nr-app-sidebar{background-color:#fff;width:220px !important;padding:15px 25px;-webkit-box-shadow:2px 0 2px 2px rgba(0,0,0,0.06);box-shadow:2px 0 2px 2px rgba(0,0,0,0.06);position:relative}.nr-app-sidebar .nav ul{list-style:none;margin:0;padding:0;width:100%}.nr-app-sidebar .nav li{border-bottom:solid 1px #eaeaea}.nr-app-sidebar .nav li.active>a{color:green;font-weight:bold;pointer-events:none}.nr-app-sidebar .nav a{display:block;color:#777;padding:13.88889px 0;text-decoration:none;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;line-height:1}.nr-app-sidebar .nav a:hover{opacity:.8}.nr-app-sidebar .nav a .icon{width:12px;height:auto;margin-right:12.5px;opacity:.8}#status{display:none}body #system-message-container{margin:0 -20px;padding-left:0}body #system-message-container,body #system-message-container>*{-webkit-box-sizing:border-box;box-sizing:border-box}body #system-message-container .alert{border-radius:0;padding:15px 25px;line-height:1}body #system-message-container>.alert:last-child{margin:0}.subhead-collapse{margin-bottom:0px !important}.nr-app-config{margin:0 !important}#attrib-gsd .controls .gsdFastEdit{margin-left:-180px}#k2TabPlugins .controls .gsdFastEdit{min-height:330px}.download_key_actions a{margin-bottom:0 !important}


