document.addEventListener("DOMContentLoaded",function(){document.addEventListener("click",function(e){var s=e.target;if(s.closest(".gsd-oh-add-btn"))s.closest(".gsd-oh-row").querySelector(".oh-picker.first").classList.add("is-visible"),s.closest(".gsd-oh-row").querySelector(".gsd-oh-add-btn").classList.add("is-hidden"),(t=s.closest(".gsd-oh-row").querySelector(".gsd-oh-more-btn")).classList.remove("is-hidden"),e.preventDefault();else if(s.closest(".gsd-oh-more-btn")){(t=s.closest(".gsd-oh-more-btn")).classList.add("is-hidden"),t.nextElementSibling.classList.toggle("is-visible"),e.preventDefault()}else if(s.closest(".gsd-oh-remove-btn")){var t;(t=s.closest(".gsd-oh-row").querySelector(".gsd-oh-more-btn")).classList.remove("is-hidden"),s.closest(".oh-more").classList.toggle("is-visible"),s.closest(".oh-more").querySelectorAll('input[type="text"]').forEach(function(e){e.value=""}),e.preventDefault()}})});

